@@ -6,4 +6,7 @@ registerFileExtension('ttf', FSFile)
 registerFileExtension('svg', FSFile)
 registerFileExtension('woff', FSFile)
 registerFileExtension('eot', FSFile)
-registerMetaType('File', FSFile)
\ No newline at end of file
+registerMetaType('File', FSFile)
+
+def initialize(context):
+    pass
\ No newline at end of file
